Index: /trunk/archive/pslib/include/psAstrom.h
===================================================================
--- /trunk/archive/pslib/include/psAstrom.h	(revision 286)
+++ /trunk/archive/pslib/include/psAstrom.h	(revision 287)
@@ -103,10 +103,10 @@
 } psChip;
 
-/** a Cell: a collection of frames.
- */
-typedef struct {
-    int nFrames;			///< number of frames in this cell realization; each may have its own
-					///< image, objects and overscan.
-    struct psFrame *frames;		//!< Frames from the cell
+/** a Cell: a collection of readouts.
+ */
+typedef struct {
+    int nReadouts;			///< number of readouts in this cell realization; each may have its
+					///< own image, objects and overscan.
+    struct psReadout *readouts;		//!< Readouts from the cell
     psMetaDataSet *md;			///< Cell-level metadata
 
@@ -118,5 +118,5 @@
 } psCell;
 
 /** a Frame: a collection of pixels */
 typedef struct {
     const int x0, y0;			//!< Offset from the lower-left corner
@@ -124,6 +124,6 @@
     psDlist *objects;			///< objects derived from cell
     psImage *overscan;                  ///< bias region (subimage) of cell
-    psMetaDataSet *md;			//!< Frame-level metadata
-} psFrame;
+    psMetaDataSet *md;			//!< Readout-level metadata
+} psReadout;
     
 
@@ -118,5 +118,5 @@
 } psCell;
 
-/** a Frame: a collection of pixels */
+/** a Readout: a collection of pixels */
 typedef struct {
     const int x0, y0;			//!< Offset from the lower-left corner
